==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__port.js <==
var group__pw__port =
[
    [ "pw_port_info", "structpw__port__info.html", [
      [ "change_mask", "structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa", null ],
      [ "direction", "structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2", null ],
      [ "id", "structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64", null ],
      [ "n_params", "structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a", null ],
      [ "params", "structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c", null ],
      [ "props", "structpw__port__info.html#a016b0b8ee30c88e43179f634c3549ada", null ]
    ] ],
    [ "pw_port_events", "structpw__port__events.html", [
      [ "info", "structpw__port__events.html#a287b7ffb7f8f5b99b82bdd61d137cb1f", null ],
      [ "param", "structpw__port__events.html#ac3ad235f94b8be2c65b694c8ebf26457", null ],
      [ "version", "structpw__port__events.html#ab9b6466b9ef1ed29b53c585e6d7d5885", null ]
    ] ],
    [ "pw_port_methods", "structpw__port__methods.html", [
      [ "add_listener", "structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd", null ],
      [ "enum_params", "structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8", null ],
      [ "subscribe_params", "structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a", null ],
      [ "version", "structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186", null ]
    ] ],
    [ "pw_direction", "group__pw__port.html#gab2082f9bafca5d7d9ff6c53fb3431823", null ],
    [ "PW_DIRECTION_INPUT", "group__pw__port.html#gac8fe785592185f71666d2d03903cc367", null ],
    [ "PW_DIRECTION_OUTPUT", "group__pw__port.html#gac245481d75b73061398575ed44ab3e07", null ],
    [ "pw_port_add_listener", "group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f", null ],
    [ "pw_port_enum_params", "group__pw__port.html#ga866d33374688faec738124490db2877e", null ],
    [ "PW_PORT_EVENT_INFO", "group__pw__port.html#ga0f310d02527226da27151627692f999b", null ],
    [ "PW_PORT_EVENT_NUM", "group__pw__port.html#ga3e912fde083fd69eca50d503c041eabb", null ],
    [ "PW_PORT_EVENT_PARAM", "group__pw__port.html#ga9ca65febfd5440fa24c17ae89da5c0bd", null ],
    [ "pw_port_method", "group__pw__port.html#ga0a2b3393a17045c7f8a6ff004c8c7f33", null ],
    [ "PW_PORT_METHOD_ADD_LISTENER", "group__pw__port.html#ga5c505757aec81210eabf84b1f9593e70", null ],
    [ "PW_PORT_METHOD_ENUM_PARAMS", "group__pw__port.html#ga1ed9c2e11f128b205fa467a2c0f19fe1", null ],
    [ "PW_PORT_METHOD_NUM", "group__pw__port.html#ga65cece0b739dc2a020a9ded0b26a22a3", null ],
    [ "PW_PORT_METHOD_SUBSCRIBE_PARAMS", "group__pw__port.html#gada3484ae34475c97571c091b7494d7b3", null ],
    [ "pw_port_subscribe_params", "group__pw__port.html#gad14c54cfcc288a9b8b8f01fe54a86a5d", null ],
    [ "PW_TYPE_INTERFACE_Port", "group__pw__port.html#ga08be9849ba07abfd630fcc2b9094e132", null ],
    [ "PW_VERSION_PORT", "group__pw__port.html#ga32a9f01e1dde49d9c5b6f64efe7af6e5", null ],
    [ "pw_direction_as_string", "group__pw__port.html#ga10cfbc658d844b76a5d3f3528cd2f345", null ],
    [ "pw_port_info_free", "group__pw__port.html#ga6ab4af1a18861478a1a9c24f3f59ea79", null ],
    [ "pw_port_info_merge", "group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190", null ],
    [ "pw_port_info_update", "group__pw__port.html#ga95a863ccc61e0293ae494345bbd51e19", null ]
];

==> pipewire-docs-1%3A0.3.39-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__port.js <==
var group__pw__port =
[
    [ "port.h", "port_8h.html", null ],
    [ "pw_port_info", "structpw__port__info.html", [
      [ "id", "structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64", null ],
      [ "direction", "structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2", null ],
      [ "change_mask", "structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa", null ],
      [ "params", "structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c", null ],
      [ "n_params", "structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a", null ]
    ] ],
    [ "pw_port_events", "structpw__port__events.html", [
      [ "version", "structpw__port__events.html#ab9b6466b9ef1ed29b53c585e6d7d5885", null ],
      [ "info", "structpw__port__events.html#a287b7ffb7f8f5b99b82bdd61d137cb1f", null ],
      [ "param", "structpw__port__events.html#ac3ad235f94b8be2c65b694c8ebf26457", null ]
    ] ],
    [ "pw_port_methods", "structpw__port__methods.html", [
      [ "version", "structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186", null ],
      [ "add_listener", "structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd", null ],
      [ "subscribe_params", "structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a", null ],
      [ "enum_params", "structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8", null ]
    ] ],
    [ "pw_port", "structpw__port.html", null ],
    [ "PW_TYPE_INTERFACE_Port", "group__pw__port.html#ga08be9849ba07abfd630fcc2b9094e132", null ],
    [ "PW_VERSION_PORT", "group__pw__port.html#ga32a9f01e1dde49d9c5b6f64efe7af6e5", null ],
    [ "pw_direction", "group__pw__port.html#gab2082f9bafca5d7d9ff6c53fb3431823", null ],
    [ "PW_DIRECTION_INPUT", "group__pw__port.html#gac8fe785592185f71666d2d03903cc367", null ],
    [ "PW_DIRECTION_OUTPUT", "group__pw__port.html#gac245481d75b73061398575ed44ab3e07", null ],
    [ "PW_PORT_CHANGE_MASK_PROPS", "group__pw__port.html#gac556c0b1548946709e9e99daa8b52b1b", null ],
    [ "PW_PORT_CHANGE_MASK_PARAMS", "group__pw__port.html#ga6e316525982a94659dfd8b86d9090c02", null ],
    [ "PW_PORT_CHANGE_MASK_ALL", "group__pw__port.html#gaf355e07f1fb54c06af8e1040c47bd1c3", null ],
    [ "PW_PORT_EVENT_INFO", "group__pw__port.html#ga0f310d02527226da27151627692f999b", null ],
    [ "PW_PORT_EVENT_PARAM", "group__pw__port.html#ga9ca65febfd5440fa24c17ae89da5c0bd", null ],
    [ "PW_PORT_EVENT_NUM", "group__pw__port.html#ga3e912fde083fd69eca50d503c041eabb", null ],
    [ "PW_VERSION_PORT_EVENTS", "group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26", null ],
    [ "PW_PORT_METHOD_ADD_LISTENER", "group__pw__port.html#ga5c505757aec81210eabf84b1f9593e70", null ],
    [ "PW_PORT_METHOD_SUBSCRIBE_PARAMS", "group__pw__port.html#gada3484ae34475c97571c091b7494d7b3", null ],
    [ "PW_PORT_METHOD_ENUM_PARAMS", "group__pw__port.html#ga1ed9c2e11f128b205fa467a2c0f19fe1", null ],
    [ "PW_PORT_METHOD_NUM", "group__pw__port.html#ga65cece0b739dc2a020a9ded0b26a22a3", null ],
    [ "PW_VERSION_PORT_METHODS", "group__pw__port.html#ga7458b44dfe9ccfb564276d814a49e94a", null ],
    [ "pw_port_method", "group__pw__port.html#ga0a2b3393a17045c7f8a6ff004c8c7f33", null ],
    [ "pw_port_add_listener", "group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f", null ],
    [ "pw_port_subscribe_params", "group__pw__port.html#gad14c54cfcc288a9b8b8f01fe54a86a5d", null ],
    [ "pw_port_enum_params", "group__pw__port.html#ga866d33374688faec738124490db2877e", null ],
    [ "pw_direction_as_string", "group__pw__port.html#ga10cfbc658d844b76a5d3f3528cd2f345", null ],
    [ "pw_port_info_update", "group__pw__port.html#ga95a863ccc61e0293ae494345bbd51e19", null ],
    [ "pw_port_info_merge", "group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190", null ],
    [ "pw_port_info_free", "group__pw__port.html#ga6ab4af1a18861478a1a9c24f3f59ea79", null ]
];
